@@ -20,8 +20,8 @@ UNICODE_FORMAT = "NFC"
 # Photos 3.0 (10.13.6) == 3301
 # Photos 4.0 (10.14.5) == 4016
 # Photos 4.0 (10.14.6) == 4025
-# Photos 5.0 (10.15.0) == 6000
-_TESTED_DB_VERSIONS = ["6000", "4025", "4016", "3301", "2622"]
+# Photos 5.0 (10.15.0) == 6000 or 5001
+_TESTED_DB_VERSIONS = ["6000", "5001", "4025", "4016", "3301", "2622"]
 
 # database model versions (applies to Photos 5, Photos 6)
 # these come from PLModelVersion key in binary plist in Z_METADATA.Z_PLIST
@@ -37,12 +37,15 @@ _PHOTOS_3_VERSION = "3301"
 
 # versions 5.0 and later have a different database structure
 _PHOTOS_4_VERSION = "4025"  # latest Mojove version on 10.14.6
-_PHOTOS_5_VERSION = "6000"  # seems to be current on 10.15.1 through 10.15.7 (also Big Sur and Monterey which switch to model version)
+_PHOTOS_5_VERSION = "5000"  # I've seen both 5001 and 6000.  6000 is most common on Catalina and up but there are some version 5001 database in the wild
 
 # Ranges for model version by Photos version
 _PHOTOS_5_MODEL_VERSION = [13000, 13999]
 _PHOTOS_6_MODEL_VERSION = [14000, 14999]
-_PHOTOS_7_MODEL_VERSION = [15000, 15999]  # Monterey developer preview is 15134
+_PHOTOS_7_MODEL_VERSION = [
+    15000,
+    15999,
+]  # Monterey developer preview is 15134, 12.1 is 15331
 
 # some table names differ between Photos 5 and Photos 6
 _DB_TABLE_NAMES = {
@@ -98,6 +101,8 @@ _TESTED_OS_VERSIONS = [
     ("11", "4"),
     ("11", "5"),
     ("11", "6"),
+    ("12", "0"),
+    ("12", "1"),
 ]
 
 # Photos 5 has persons who are empty string if unidentified face
@@ -258,7 +263,7 @@ EXTENDED_ATTRIBUTE_NAMES_QUOTED = [f"'{x}'" for x in EXTENDED_ATTRIBUTE_NAMES]
 OSXPHOTOS_EXPORT_DB = ".osxphotos_export.db"
 
 # bit flags for burst images ("burstPickType")
-BURST_PICK_TYPE_NONE = 0b0 # 0: sometimes used for single images with a burst UUID
+BURST_PICK_TYPE_NONE = 0b0  # 0: sometimes used for single images with a burst UUID
 BURST_NOT_SELECTED = 0b10  # 2: burst image is not selected
 BURST_DEFAULT_PICK = 0b100  # 4: burst image is the one Photos picked to be key image before any selections made
 BURST_SELECTED = 0b1000  # 8: burst image is selected
@@ -300,3 +305,21 @@ class AlbumSortOrder(Enum):
 
 
 TEXT_DETECTION_CONFIDENCE_THRESHOLD = 0.75
+
+# stat sort order for cProfile: https://docs.python.org/3/library/profile.html#pstats.Stats.sort_stats
+PROFILE_SORT_KEYS = [
+    "calls",
+    "cumulative",
+    "cumtime",
+    "file",
+    "filename",
+    "module",
+    "ncalls",
+    "pcalls",
+    "line",
+    "name",
+    "nfl",
+    "stdname",
+    "time",
+    "tottime",
+]
