@@ -10,11 +10,17 @@ import sys
 from abc import ABC, abstractmethod
 from io import StringIO
 from sqlite3 import Error
+from typing import Union
 
 from ._constants import OSXPHOTOS_EXPORT_DB
 from ._version import __version__
+from .utils import normalize_fs_path
+
+__all__ = ["ExportDB_ABC", "ExportDBNoOp", "ExportDB", "ExportDBInMemory"]
+
+OSXPHOTOS_EXPORTDB_VERSION = "4.3"
+OSXPHOTOS_EXPORTDB_VERSION_MIGRATE_FILEPATH = "4.3"
 
-OSXPHOTOS_EXPORTDB_VERSION = "4.0"
 OSXPHOTOS_ABOUT_STRING = f"Created by osxphotos version {__version__} (https://github.com/RhetTbull/osxphotos) on {datetime.datetime.now()}"
 
 
@@ -102,12 +108,12 @@ class ExportDB_ABC(ABC):
         self,
         filename,
         uuid,
-        orig_stat,
-        exif_stat,
-        converted_stat,
-        edited_stat,
-        info_json,
-        exif_json,
+        orig_stat=None,
+        exif_stat=None,
+        converted_stat=None,
+        edited_stat=None,
+        info_json=None,
+        exif_json=None,
     ):
         pass
 
@@ -181,12 +187,12 @@ class ExportDBNoOp(ExportDB_ABC):
         self,
         filename,
         uuid,
-        orig_stat,
-        exif_stat,
-        converted_stat,
-        edited_stat,
-        info_json,
-        exif_json,
+        orig_stat=None,
+        exif_stat=None,
+        converted_stat=None,
+        edited_stat=None,
+        info_json=None,
+        exif_json=None,
     ):
         pass
 
@@ -209,12 +215,13 @@ class ExportDB(ExportDB_ABC):
         """query database for filename and return UUID
         returns None if filename not found in database
         """
-        filename = str(pathlib.Path(filename).relative_to(self._path)).lower()
+        filepath_normalized = self._normalize_filepath_relative(filename)
         conn = self._conn
         try:
             c = conn.cursor()
             c.execute(
-                "SELECT uuid FROM files WHERE filepath_normalized = ?", (filename,)
+                "SELECT uuid FROM files WHERE filepath_normalized = ?",
+                (filepath_normalized,),
             )
             results = c.fetchone()
             uuid = results[0] if results else None
@@ -226,7 +233,7 @@ class ExportDB(ExportDB_ABC):
     def set_uuid_for_file(self, filename, uuid):
         """set UUID of filename to uuid in the database"""
         filename = str(pathlib.Path(filename).relative_to(self._path))
-        filename_normalized = filename.lower()
+        filename_normalized = self._normalize_filepath(filename)
         conn = self._conn
         try:
             c = conn.cursor()
@@ -243,7 +250,7 @@ class ExportDB(ExportDB_ABC):
         """set stat info for filename
         filename: filename to set the stat info for
         stat: a tuple of length 3: mode, size, mtime"""
-        filename = str(pathlib.Path(filename).relative_to(self._path)).lower()
+        filename = self._normalize_filepath_relative(filename)
         if len(stats) != 3:
             raise ValueError(f"expected 3 elements for stat, got {len(stats)}")
 
@@ -264,7 +271,7 @@ class ExportDB(ExportDB_ABC):
         """get stat info for filename
         returns: tuple of (mode, size, mtime)
         """
-        filename = str(pathlib.Path(filename).relative_to(self._path)).lower()
+        filename = self._normalize_filepath_relative(filename)
         conn = self._conn
         try:
             c = conn.cursor()
@@ -300,7 +307,7 @@ class ExportDB(ExportDB_ABC):
         """set stat info for filename (after exiftool has updated it)
         filename: filename to set the stat info for
         stat: a tuple of length 3: mode, size, mtime"""
-        filename = str(pathlib.Path(filename).relative_to(self._path)).lower()
+        filename = self._normalize_filepath_relative(filename)
         if len(stats) != 3:
             raise ValueError(f"expected 3 elements for stat, got {len(stats)}")
 
@@ -321,7 +328,7 @@ class ExportDB(ExportDB_ABC):
         """get stat info for filename (after exiftool has updated it)
         returns: tuple of (mode, size, mtime)
         """
-        filename = str(pathlib.Path(filename).relative_to(self._path)).lower()
+        filename = self._normalize_filepath_relative(filename)
         conn = self._conn
         try:
             c = conn.cursor()
@@ -382,7 +389,7 @@ class ExportDB(ExportDB_ABC):
 
     def get_exifdata_for_file(self, filename):
         """returns the exifdata JSON struct for a file"""
-        filename = str(pathlib.Path(filename).relative_to(self._path)).lower()
+        filename = self._normalize_filepath_relative(filename)
         conn = self._conn
         try:
             c = conn.cursor()
@@ -400,7 +407,7 @@ class ExportDB(ExportDB_ABC):
 
     def set_exifdata_for_file(self, filename, exifdata):
         """sets the exifdata JSON struct for a file"""
-        filename = str(pathlib.Path(filename).relative_to(self._path)).lower()
+        filename = self._normalize_filepath_relative(filename)
         conn = self._conn
         try:
             c = conn.cursor()
@@ -414,7 +421,7 @@ class ExportDB(ExportDB_ABC):
 
     def get_sidecar_for_file(self, filename):
         """returns the sidecar data and signature for a file"""
-        filename = str(pathlib.Path(filename).relative_to(self._path)).lower()
+        filename = self._normalize_filepath_relative(filename)
         conn = self._conn
         try:
             c = conn.cursor()
@@ -442,7 +449,7 @@ class ExportDB(ExportDB_ABC):
 
     def set_sidecar_for_file(self, filename, sidecar_data, sidecar_sig):
         """sets the sidecar data and signature for a file"""
-        filename = str(pathlib.Path(filename).relative_to(self._path)).lower()
+        filename = self._normalize_filepath_relative(filename)
         conn = self._conn
         try:
             c = conn.cursor()
@@ -504,52 +511,65 @@ class ExportDB(ExportDB_ABC):
         self,
         filename,
         uuid,
-        orig_stat,
-        exif_stat,
-        converted_stat,
-        edited_stat,
-        info_json,
-        exif_json,
+        orig_stat=None,
+        exif_stat=None,
+        converted_stat=None,
+        edited_stat=None,
+        info_json=None,
+        exif_json=None,
     ):
-        """sets all the data for file and uuid at once"""
+        """sets all the data for file and uuid at once; if any value is None, does not set it"""
         filename = str(pathlib.Path(filename).relative_to(self._path))
-        filename_normalized = filename.lower()
+        filename_normalized = self._normalize_filepath(filename)
         conn = self._conn
         try:
             c = conn.cursor()
+            # update files table (if needed);
+            # this statement works around fact that there was no unique constraint on files.filepath_normalized
             c.execute(
-                "INSERT OR REPLACE INTO files(filepath, filepath_normalized, uuid) VALUES (?, ?, ?);",
+                """INSERT OR IGNORE INTO files(filepath, filepath_normalized, uuid) VALUES (?, ?, ?);""",
                 (filename, filename_normalized, uuid),
             )
 
-            c.execute(
-                "UPDATE files "
-                + "SET orig_mode = ?, orig_size = ?, orig_mtime = ? "
-                + "WHERE filepath_normalized = ?;",
-                (*orig_stat, filename_normalized),
-            )
-            c.execute(
-                "UPDATE files "
-                + "SET exif_mode = ?, exif_size = ?, exif_mtime = ? "
-                + "WHERE filepath_normalized = ?;",
-                (*exif_stat, filename_normalized),
-            )
-            c.execute(
-                "INSERT OR REPLACE INTO converted(filepath_normalized, mode, size, mtime) VALUES (?, ?, ?, ?);",
-                (filename_normalized, *converted_stat),
-            )
-            c.execute(
-                "INSERT OR REPLACE INTO edited(filepath_normalized, mode, size, mtime) VALUES (?, ?, ?, ?);",
-                (filename_normalized, *edited_stat),
-            )
-            c.execute(
-                "INSERT OR REPLACE INTO info(uuid, json_info) VALUES (?, ?);",
-                (uuid, info_json),
-            )
-            c.execute(
-                "INSERT OR REPLACE INTO exifdata(filepath_normalized, json_exifdata) VALUES (?, ?);",
-                (filename_normalized, exif_json),
-            )
+            if orig_stat is not None:
+                c.execute(
+                    "UPDATE files "
+                    + "SET orig_mode = ?, orig_size = ?, orig_mtime = ? "
+                    + "WHERE filepath_normalized = ?;",
+                    (*orig_stat, filename_normalized),
+                )
+
+            if exif_stat is not None:
+                c.execute(
+                    "UPDATE files "
+                    + "SET exif_mode = ?, exif_size = ?, exif_mtime = ? "
+                    + "WHERE filepath_normalized = ?;",
+                    (*exif_stat, filename_normalized),
+                )
+
+            if converted_stat is not None:
+                c.execute(
+                    "INSERT OR REPLACE INTO converted(filepath_normalized, mode, size, mtime) VALUES (?, ?, ?, ?);",
+                    (filename_normalized, *converted_stat),
+                )
+
+            if edited_stat is not None:
+                c.execute(
+                    "INSERT OR REPLACE INTO edited(filepath_normalized, mode, size, mtime) VALUES (?, ?, ?, ?);",
+                    (filename_normalized, *edited_stat),
+                )
+
+            if info_json is not None:
+                c.execute(
+                    "INSERT OR REPLACE INTO info(uuid, json_info) VALUES (?, ?);",
+                    (uuid, info_json),
+                )
+
+            if exif_json is not None:
+                c.execute(
+                    "INSERT OR REPLACE INTO exifdata(filepath_normalized, json_exifdata) VALUES (?, ?);",
+                    (filename_normalized, exif_json),
+                )
             conn.commit()
         except Error as e:
             logging.warning(e)
@@ -562,7 +582,7 @@ class ExportDB(ExportDB_ABC):
             logging.warning(e)
 
     def _set_stat_for_file(self, table, filename, stats):
-        filename = str(pathlib.Path(filename).relative_to(self._path)).lower()
+        filename = self._normalize_filepath_relative(filename)
         if len(stats) != 3:
             raise ValueError(f"expected 3 elements for stat, got {len(stats)}")
 
@@ -575,7 +595,7 @@ class ExportDB(ExportDB_ABC):
         conn.commit()
 
     def _get_stat_for_file(self, table, filename):
-        filename = str(pathlib.Path(filename).relative_to(self._path)).lower()
+        filename = self._normalize_filepath_relative(filename)
         conn = self._conn
         c = conn.cursor()
         c.execute(
@@ -611,6 +631,8 @@ class ExportDB(ExportDB_ABC):
             version_info = self._get_database_version(conn)
             if version_info[1] < OSXPHOTOS_EXPORTDB_VERSION:
                 self._create_db_tables(conn)
+                if version_info[1] < OSXPHOTOS_EXPORTDB_VERSION_MIGRATE_FILEPATH:
+                    self._migrate_normalized_filepath(conn)
                 self.was_upgraded = (version_info[1], OSXPHOTOS_EXPORTDB_VERSION)
             else:
                 self.was_upgraded = ()
@@ -660,6 +682,22 @@ class ExportDB(ExportDB_ABC):
                               exif_size INTEGER,
                               exif_mtime REAL
                               ); """,
+            "sql_files_table_migrate": """ CREATE TABLE IF NOT EXISTS files_migrate (
+                              id INTEGER PRIMARY KEY,
+                              filepath TEXT NOT NULL,
+                              filepath_normalized TEXT NOT NULL,
+                              uuid TEXT,
+                              orig_mode INTEGER,
+                              orig_size INTEGER,
+                              orig_mtime REAL,
+                              exif_mode INTEGER,
+                              exif_size INTEGER,
+                              exif_mtime REAL,
+                              UNIQUE(filepath_normalized)
+                              ); """,
+            "sql_files_migrate": """ INSERT INTO files_migrate SELECT * FROM files;""",
+            "sql_files_drop_tables": """ DROP TABLE files;""",
+            "sql_files_alter": """ ALTER TABLE files_migrate RENAME TO files;""",
             "sql_runs_table": """ CREATE TABLE IF NOT EXISTS runs (
                              id INTEGER PRIMARY KEY,
                              datetime TEXT,
@@ -751,6 +789,32 @@ class ExportDB(ExportDB_ABC):
         except Error as e:
             logging.warning(e)
 
+    def _normalize_filepath(self, filepath: Union[str, pathlib.Path]) -> str:
+        """normalize filepath for unicode, lower case"""
+        return normalize_fs_path(str(filepath)).lower()
+
+    def _normalize_filepath_relative(self, filepath: Union[str, pathlib.Path]) -> str:
+        """normalize filepath for unicode, relative path (to export dir), lower case"""
+        filepath = str(pathlib.Path(filepath).relative_to(self._path))
+        return normalize_fs_path(str(filepath)).lower()
+
+    def _migrate_normalized_filepath(self, conn):
+        """Fix all filepath_normalized columns for unicode normalization"""
+        # Prior to database version 4.3, filepath_normalized was not normalized for unicode
+        c = conn.cursor()
+        for table in ["converted", "edited", "exifdata", "files", "sidecar"]:
+            old_values = c.execute(
+                f"SELECT filepath_normalized, id FROM {table}"
+            ).fetchall()
+            new_values = [
+                (self._normalize_filepath(filepath_normalized), id_)
+                for filepath_normalized, id_ in old_values
+            ]
+            c.executemany(
+                f"UPDATE {table} SET filepath_normalized=? WHERE id=?", new_values
+            )
+        conn.commit()
+
 
 class ExportDBInMemory(ExportDB):
     """In memory version of ExportDB
