@@ -11,9 +11,11 @@ import Foundation
 
 from .imageconverter import ImageConverter
 
+__all__ = ["FileUtilABC", "FileUtilMacOS", "FileUtil", "FileUtilNoOp"]
+
 
 class FileUtilABC(ABC):
-    """ Abstract base class for FileUtil """
+    """Abstract base class for FileUtil"""
 
     @classmethod
     @abstractmethod
@@ -67,14 +69,14 @@ class FileUtilABC(ABC):
 
 
 class FileUtilMacOS(FileUtilABC):
-    """ Various file utilities """
+    """Various file utilities"""
 
     @classmethod
     def hardlink(cls, src, dest):
-        """ Hardlinks a file from src path to dest path 
-            src: source path as string 
-            dest: destination path as string
-            Raises exception if linking fails or either path is None """
+        """Hardlinks a file from src path to dest path
+        src: source path as string
+        dest: destination path as string
+        Raises exception if linking fails or either path is None"""
 
         if src is None or dest is None:
             raise ValueError("src and dest must not be None", src, dest)
@@ -90,17 +92,17 @@ class FileUtilMacOS(FileUtilABC):
 
     @classmethod
     def copy(cls, src, dest):
-        """ Copies a file from src path to dest path 
-        
+        """Copies a file from src path to dest path
+
         Args:
             src: source path as string; must be a valid file path
             dest: destination path as string
                   dest may be either directory or file; in either case, src file must not exist in dest
             Note: src and dest may be either a string or a pathlib.Path object
-        
+
         Returns:
             True if copy succeeded
-        
+
         Raises:
             OSError if copy fails
             TypeError if either path is None
@@ -124,7 +126,7 @@ class FileUtilMacOS(FileUtilABC):
 
     @classmethod
     def unlink(cls, filepath):
-        """ unlink filepath; if it's pathlib.Path, use Path.unlink, otherwise use os.unlink """
+        """unlink filepath; if it's pathlib.Path, use Path.unlink, otherwise use os.unlink"""
         if isinstance(filepath, pathlib.Path):
             filepath.unlink()
         else:
@@ -132,7 +134,7 @@ class FileUtilMacOS(FileUtilABC):
 
     @classmethod
     def rmdir(cls, dirpath):
-        """ remove directory filepath; dirpath must be empty """
+        """remove directory filepath; dirpath must be empty"""
         if isinstance(dirpath, pathlib.Path):
             dirpath.rmdir()
         else:
@@ -140,7 +142,7 @@ class FileUtilMacOS(FileUtilABC):
 
     @classmethod
     def utime(cls, path, times):
-        """ Set the access and modified time of path. """
+        """Set the access and modified time of path."""
         os.utime(path, times)
 
     @classmethod
@@ -152,7 +154,7 @@ class FileUtilMacOS(FileUtilABC):
         mtime1 -- optional, pass alternate file modification timestamp for f1; will be converted to int
 
         Return value:
-        True if the file signatures as returned by stat are the same, False otherwise. 
+        True if the file signatures as returned by stat are the same, False otherwise.
         Does not do a byte-by-byte comparison.
         """
 
@@ -179,27 +181,26 @@ class FileUtilMacOS(FileUtilABC):
             return False
 
         s1 = cls._sig(os.stat(f1))
-
         if s1[0] != stat.S_IFREG or s2[0] != stat.S_IFREG:
             return False
         return s1 == s2
 
     @classmethod
     def file_sig(cls, f1):
-        """ return os.stat signature for file f1 """
+        """return os.stat signature for file f1"""
         return cls._sig(os.stat(f1))
 
     @classmethod
     def convert_to_jpeg(cls, src_file, dest_file, compression_quality=1.0):
-        """ converts image file src_file to jpeg format as dest_file
+        """converts image file src_file to jpeg format as dest_file
 
-            Args:
-                src_file: image file to convert
-                dest_file: destination path to write converted file to
-                compression quality: JPEG compression quality in range 0.0 <= compression_quality <= 1.0; default 1.0 (best quality)
-                
-            Returns:
-                True if success, otherwise False 
+        Args:
+            src_file: image file to convert
+            dest_file: destination path to write converted file to
+            compression quality: JPEG compression quality in range 0.0 <= compression_quality <= 1.0; default 1.0 (best quality)
+
+        Returns:
+            True if success, otherwise False
         """
         converter = ImageConverter()
         return converter.write_jpeg(
@@ -208,40 +209,40 @@ class FileUtilMacOS(FileUtilABC):
 
     @classmethod
     def rename(cls, src, dest):
-        """ Copy src to dest 
+        """Copy src to dest
 
         Args:
             src: path to source file
             dest: path to destination file
-        
+
         Returns:
             Name of renamed file (dest)
-        
+
         """
         os.rename(str(src), str(dest))
         return dest
 
     @staticmethod
     def _sig(st):
-        """ return tuple of (mode, size, mtime) of file based on os.stat
-            Args:
-                st: os.stat signature
+        """return tuple of (mode, size, mtime) of file based on os.stat
+        Args:
+            st: os.stat signature
         """
         # use int(st.st_mtime) because ditto does not copy fractional portion of mtime
         return (stat.S_IFMT(st.st_mode), st.st_size, int(st.st_mtime))
 
 
 class FileUtil(FileUtilMacOS):
-    """ Various file utilities """
+    """Various file utilities"""
 
     pass
 
 
 class FileUtilNoOp(FileUtil):
-    """ No-Op implementation of FileUtil for testing / dry-run mode
-        all methods with exception of cmp, cmp_file_sig and file_cmp are no-op
-        cmp and cmp_file_sig functions as FileUtil methods do
-        file_cmp returns mock data
+    """No-Op implementation of FileUtil for testing / dry-run mode
+    all methods with exception of cmp, cmp_file_sig and file_cmp are no-op
+    cmp and cmp_file_sig functions as FileUtil methods do
+    file_cmp returns mock data
     """
 
     @staticmethod
