@@ -1,5 +1,6 @@
 """ Utility functions used in osxphotos """
 
+import datetime
 import fnmatch
 import glob
 import importlib
@@ -16,14 +17,30 @@ import sys
 import unicodedata
 import urllib.parse
 from plistlib import load as plistload
-from typing import Callable, Union
+from typing import Callable, List, Union, Optional
 
 import CoreFoundation
 import objc
-from Foundation import NSString
+from Foundation import NSFileManager, NSPredicate, NSString
 
 from ._constants import UNICODE_FORMAT
 
+__all__ = [
+    "dd_to_dms_str",
+    "expand_and_validate_filepath",
+    "get_last_library_path",
+    "get_system_library_path",
+    "increment_filename_with_count",
+    "increment_filename",
+    "lineno",
+    "list_directory",
+    "list_photo_libraries",
+    "load_function",
+    "noop",
+    "normalize_fs_path",
+    "normalize_unicode",
+]
+
 _DEBUG = False
 
 
@@ -248,7 +265,9 @@ def list_photo_libraries():
     # On older MacOS versions, mdfind appears to ignore some libraries
     # glob to find libraries in ~/Pictures then mdfind to find all the others
     # TODO: make this more robust
-    lib_list = glob.glob(f"{str(pathlib.Path.home())}/Pictures/*.photoslibrary")
+    lib_list = list_directory(
+        f"{pathlib.Path.home()}/Pictures/", glob="*.photoslibrary"
+    )
 
     # On older OS, may not get all libraries so make sure we get the last one
     last_lib = get_last_library_path()
@@ -267,24 +286,95 @@ def list_photo_libraries():
 
 def normalize_fs_path(path: str) -> str:
     """Normalize filesystem paths with unicode in them"""
-    with objc.autorelease_pool():
-        normalized_path = NSString.fileSystemRepresentation(path)
-        return normalized_path.decode("utf8")
+    # macOS HFS+ uses NFD, APFS doesn't normalize but stick with NFD
+    # ref: https://eclecticlight.co/2021/05/08/explainer-unicode-normalization-and-apfs/
+    return unicodedata.normalize("NFD", path)
 
 
-def findfiles(pattern, path_):
-    """Returns list of filenames from path_ matched by pattern
-    shell pattern. Matching is case-insensitive.
-    If 'path_' is invalid/doesn't exist, returns []."""
-    if not os.path.isdir(path_):
+# def findfiles(pattern, path):
+#     """Returns list of filenames from path matched by pattern
+#     shell pattern. Matching is case-insensitive.
+#     If 'path_' is invalid/doesn't exist, returns []."""
+#     if not os.path.isdir(path):
+#         return []
+
+#     # paths need to be normalized for unicode as filesystem returns unicode in NFD form
+#     pattern = normalize_fs_path(pattern)
+#     rule = re.compile(fnmatch.translate(pattern), re.IGNORECASE)
+#     files = os.listdir(path)
+#     return [name for name in files if rule.match(name)]
+
+
+def list_directory(
+    directory: Union[str, pathlib.Path],
+    startswith: Optional[str] = None,
+    endswith: Optional[str] = None,
+    contains: Optional[str] = None,
+    glob: Optional[str] = None,
+    include_path: bool = False,
+    case_sensitive: bool = False,
+) -> List[Union[str, pathlib.Path]]:
+    """List directory contents and return list of files or directories matching search criteria.
+    Accounts for case-insensitive filesystems, unicode filenames. directory can be a str or a pathlib.Path object.
+
+    Args:
+        directory: directory to search
+        startswith: string to match at start of filename
+        endswith: string to match at end of filename
+        contains: string to match anywhere in filename
+        glob: shell-style glob pattern to match filename
+        include_path: if True, return full path to file
+        case_sensitive: if True, match case-sensitively
+
+    Returns: List of files or directories matching search criteria as either str or pathlib.Path objects depending on the input type;
+    returns empty list if directory is invalid or doesn't exist.
+
+    """
+    is_pathlib = isinstance(directory, pathlib.Path)
+    if is_pathlib:
+        directory = str(directory)
+
+    if not os.path.isdir(directory):
         return []
-    # See: https://gist.github.com/techtonik/5694830
 
-    # paths need to be normalized for unicode as filesystem returns unicode in NFD form
-    pattern = normalize_fs_path(pattern)
-    rule = re.compile(fnmatch.translate(pattern), re.IGNORECASE)
-    files = [normalize_fs_path(p) for p in os.listdir(path_)]
-    return [name for name in files if rule.match(name)]
+    startswith = normalize_fs_path(startswith) if startswith else None
+    endswith = normalize_fs_path(endswith) if endswith else None
+    contains = normalize_fs_path(contains) if contains else None
+    glob = normalize_fs_path(glob) if glob else None
+
+    files = [normalize_fs_path(f) for f in os.listdir(directory)]
+    if not case_sensitive:
+        files_normalized = {f.lower(): f for f in files}
+        files = [f.lower() for f in files]
+        startswith = startswith.lower() if startswith else None
+        endswith = endswith.lower() if endswith else None
+        contains = contains.lower() if contains else None
+        glob = glob.lower() if glob else None
+    else:
+        files_normalized = {f: f for f in files}
+
+    if startswith:
+        files = [f for f in files if f.startswith(startswith)]
+    if endswith:
+        endswith = normalize_fs_path(endswith)
+        files = [f for f in files if f.endswith(endswith)]
+    if contains:
+        contains = normalize_fs_path(contains)
+        files = [f for f in files if contains in f]
+    if glob:
+        glob = normalize_fs_path(glob)
+        flags = re.IGNORECASE if not case_sensitive else 0
+        rule = re.compile(fnmatch.translate(glob), flags)
+        files = [f for f in files if rule.match(f)]
+
+    files = [files_normalized[f] for f in files]
+
+    if include_path:
+        files = [os.path.join(directory, f) for f in files]
+    if is_pathlib:
+        files = [pathlib.Path(f) for f in files]
+
+    return files
 
 
 def _open_sql_file(dbname):
@@ -325,47 +415,21 @@ def _db_is_locked(dbname):
     return locked
 
 
-# OSXPHOTOS_XATTR_UUID = "com.osxphotos.uuid"
-
-# def get_uuid_for_file(filepath):
-#     """ returns UUID associated with an exported file
-#         filepath: path to exported photo
-#     """
-#     attr = xattr.xattr(filepath)
-#     try:
-#         uuid_bytes = attr[OSXPHOTOS_XATTR_UUID]
-#         uuid_str = uuid_bytes.decode('utf-8')
-#     except KeyError:
-#         uuid_str = None
-#     return uuid_str
-
-# def set_uuid_for_file(filepath, uuid):
-#     """ sets the UUID associated with an exported file
-#         filepath: path to exported photo
-#         uuid: uuid string for photo
-#     """
-#     if not os.path.exists(filepath):
-#         raise FileNotFoundError(f"Missing file: {filepath}")
-
-#     attr = xattr.xattr(filepath)
-#     uuid_bytes = bytes(uuid, 'utf-8')
-#     attr.set(OSXPHOTOS_XATTR_UUID, uuid_bytes)
-
-
 def normalize_unicode(value):
     """normalize unicode data"""
-    if value is not None:
-        if isinstance(value, (tuple, list)):
-            return tuple(unicodedata.normalize(UNICODE_FORMAT, v) for v in value)
-        elif isinstance(value, str):
-            return unicodedata.normalize(UNICODE_FORMAT, value)
-        else:
-            return value
-    else:
+    if value is None:
         return None
+    if isinstance(value, (tuple, list)):
+        return tuple(unicodedata.normalize(UNICODE_FORMAT, v) for v in value)
+    elif isinstance(value, str):
+        return unicodedata.normalize(UNICODE_FORMAT, value)
+    else:
+        return value
 
 
-def increment_filename_with_count(filepath: Union[str,pathlib.Path], count: int = 0) -> str:
+def increment_filename_with_count(
+    filepath: Union[str, pathlib.Path], count: int = 0
+) -> str:
     """Return filename (1).ext, etc if filename.ext exists
 
         If file exists in filename's parent folder with same stem as filename,
@@ -381,16 +445,16 @@ def increment_filename_with_count(filepath: Union[str,pathlib.Path], count: int
     Note: This obviously is subject to race condition so using with caution.
     """
     dest = filepath if isinstance(filepath, pathlib.Path) else pathlib.Path(filepath)
-    dest_files = findfiles(f"{dest.stem}*", str(dest.parent))
-    dest_files = [normalize_fs_path(pathlib.Path(f).stem.lower()) for f in dest_files]
-    dest_new = dest.stem
-    if count:
-        dest_new = f"{dest.stem} ({count})"
-    while normalize_fs_path(dest_new.lower()) in dest_files:
+    dest_files = list_directory(dest.parent, startswith=dest.stem)
+    dest_files = [f.stem.lower() for f in dest_files]
+    dest_new = f"{dest.stem} ({count})" if count else dest.stem
+    dest_new = normalize_fs_path(dest_new)
+
+    while dest_new.lower() in dest_files:
         count += 1
-        dest_new = f"{dest.stem} ({count})"
+        dest_new = normalize_fs_path(f"{dest.stem} ({count})")
     dest = dest.parent / f"{dest_new}{dest.suffix}"
-    return str(dest), count
+    return normalize_fs_path(str(dest)), count
 
 
 def increment_filename(filepath: Union[str, pathlib.Path]) -> str:
@@ -448,3 +512,9 @@ def load_function(pyfile: str, function_name: str) -> Callable:
         sys.path = syspath
 
     return func
+
+
+def format_sec_to_hhmmss(sec: float) -> str:
+    """Format seconds to hh:mm:ss"""
+    delta = datetime.timedelta(seconds=sec)
+    return str(delta).split(".")[0]
